@@ -194,18 +194,18 @@ class CoreEnforcer:
     def load_policy(self):
         """reloads the policy from file/database."""
         need_to_rebuild = False
-        new_model = copy.copy(self.model)
+        new_model = copy.deepcopy(self.model)
         new_model.clear_policy()
 
         try:
 
             self.adapter.load_policy(new_model)
 
-            self.model.sort_policies_by_subject_hierarchy()
+            new_model.sort_policies_by_subject_hierarchy()
 
             new_model.sort_policies_by_priority()
 
-            self.model.print_policy()
+            new_model.print_policy()
 
             if self.auto_build_role_links:
 
@@ -214,7 +214,6 @@ class CoreEnforcer:
                     rm.clear()
 
                 new_model.build_role_links(self.rm_map)
-                self.build_role_links()
 
             self.model = new_model
 
