@@ -1,3 +1,17 @@
+# Copyright 2021 The casbin Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from casbin import SyncedEnforcer
 import logging
 
@@ -35,9 +49,7 @@ class DistributedEnforcer(SyncedEnforcer):
 
         if sec == "g":
             try:
-                self.build_incremental_role_links(
-                    PolicyOp.Policy_add, ptype, no_exists_policy
-                )
+                self.build_incremental_role_links(PolicyOp.Policy_add, ptype, no_exists_policy)
             except Exception as e:
                 self.logger.log("An exception occurred: " + e)
                 return no_exists_policy
@@ -67,9 +79,7 @@ class DistributedEnforcer(SyncedEnforcer):
 
         return effected
 
-    def remove_filtered_policy_self(
-        self, should_persist, sec, ptype, field_index, *field_values
-    ):
+    def remove_filtered_policy_self(self, should_persist, sec, ptype, field_index, *field_values):
         """
         remove_filtered_policy_self provides a method for dispatcher to remove an authorization
         rule from the current policy,field filters can be specified.
@@ -77,21 +87,15 @@ class DistributedEnforcer(SyncedEnforcer):
         """
         if should_persist:
             try:
-                self.adapter.remove_filtered_policy(
-                    sec, ptype, field_index, field_values
-                )
+                self.adapter.remove_filtered_policy(sec, ptype, field_index, field_values)
             except Exception as e:
                 self.logger.log("An exception occurred: " + e)
 
-        effects = self.get_model().remove_filtered_policy_returns_effects(
-            sec, ptype, field_index, *field_values
-        )
+        effects = self.get_model().remove_filtered_policy_returns_effects(sec, ptype, field_index, *field_values)
 
         if sec == "g":
             try:
-                self.build_incremental_role_links(
-                    PolicyOp.Policy_remove, ptype, effects
-                )
+                self.build_incremental_role_links(PolicyOp.Policy_remove, ptype, effects)
             except Exception as e:
                 self.logger.log("An exception occurred: " + e)
                 return effects
@@ -129,16 +133,12 @@ class DistributedEnforcer(SyncedEnforcer):
 
         if sec == "g":
             try:
-                self.build_incremental_role_links(
-                    PolicyOp.Policy_remove, ptype, [old_rule]
-                )
+                self.build_incremental_role_links(PolicyOp.Policy_remove, ptype, [old_rule])
             except Exception as e:
                 return False
 
             try:
-                self.build_incremental_role_links(
-                    PolicyOp.Policy_add, ptype, [new_rule]
-                )
+                self.build_incremental_role_links(PolicyOp.Policy_add, ptype, [new_rule])
             except Exception as e:
                 return False
 
