@@ -1,3 +1,17 @@
+# Copyright 2021 The casbin Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from functools import partial
 
 from casbin.management_enforcer import ManagementEnforcer
@@ -138,9 +152,7 @@ class Enforcer(ManagementEnforcer):
 
         return res
 
-    def get_implicit_permissions_for_user(
-        self, user, domain="", filter_policy_dom=True
-    ):
+    def get_implicit_permissions_for_user(self, user, domain="", filter_policy_dom=True):
         """
         gets implicit permissions for a user or role.
         Compared to get_permissions_for_user(), this function retrieves permissions for inherited roles.
@@ -152,6 +164,26 @@ class Enforcer(ManagementEnforcer):
         get_permissions_for_user("alice") can only get: [["alice", "data2", "read"]].
         But get_implicit_permissions_for_user("alice") will get: [["admin", "data1", "read"], ["alice", "data2", "read"]].
 
+        For given domain policies are filtered by corresponding domain matching function of DomainManager
+        Inherited roles can be matched by domain. For domain neutral policies set:
+         filter_policy_dom = False
+
+        filter_policy_dom: bool - For given *domain*, policies will be filtered by domain as well. Default = True
+        """
+        return self.get_named_implicit_permissions_for_user("p", user, domain, filter_policy_dom)
+
+    def get_named_implicit_permissions_for_user(self, ptype, user, domain="", filter_policy_dom=True):
+        """
+        gets implicit permissions for a user or role by named policy.
+        Compared to get_permissions_for_user(), this function retrieves permissions for inherited roles.
+        For example:
+        p, admin, data1, read
+        p, alice, data2, read
+        g, alice, admin
+
+        get_permissions_for_user("alice") can only get: [["alice", "data2", "read"]].
+        But get_implicit_permissions_for_user("alice") will get: [["admin", "data1", "read"], ["alice", "data2", "read"]].
+
         For given domain policies are filtered by corresponding domain matching function of DomainManager
         Inherited roles can be matched by domain. For domain neutral policies set:
          filter_policy_dom = False
@@ -165,12 +197,13 @@ class Enforcer(ManagementEnforcer):
         res = []
 
         # policy domain should be matched by domain_match_fn of DomainManager
-        if domain:
-            domain = partial(self.get_role_manager().domain_matching_func, domain)
+        domain_matching_func = self.get_role_manager().domain_matching_func
+        if domain and domain_matching_func != None:
+            domain = partial(domain_matching_func, domain)
 
         for role in roles:
-            permissions = self.get_permissions_for_user_in_domain(
-                role, domain if filter_policy_dom else ""
+            permissions = self.get_named_permissions_for_user_in_domain(
+                ptype, role, domain if filter_policy_dom else ""
             )
             res.extend(permissions)
 
@@ -224,4 +257,8 @@ class Enforcer(ManagementEnforcer):
 
     def get_permissions_for_user_in_domain(self, user, domain):
         """gets permissions for a user or role inside domain."""
-        return self.get_filtered_policy(0, user, domain)
+        return self.get_named_permissions_for_user_in_domain("p", user, domain)
+
+    def get_named_permissions_for_user_in_domain(self, ptype, user, domain):
+        """gets permissions for a user or role with named policy inside domain."""
+        return self.get_filtered_named_policy(ptype, 0, user, domain)
