@@ -1,3 +1,18 @@
+# Copyright 2021 The casbin Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 def load_policy_line(line, model):
     """loads a text line as a policy rule to model."""
 
@@ -17,7 +32,7 @@ def load_policy_line(line, model):
     if key not in model.model[sec].keys():
         return
 
-    model.model[sec][key].policy.append(tokens[1:])
+    model.add_policy(sec, key, tokens[1:])
 
 
 class Adapter:
