@@ -1,3 +1,17 @@
+# Copyright 2021 The casbin Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 from casbin.config import Config
 from unittest import TestCase
@@ -41,7 +55,7 @@ class TestConfig(TestCase):
 
         self.assertEqual(config.get_bool("multi5::name"), False)
         self.assertEqual(config.get_string("multi5::name"), "r.sub==p.sub && r.obj==p.obj")
-        self.assertEqual(config.get_strings("multi5::name"), ['r.sub==p.sub && r.obj==p.obj'])
+        self.assertEqual(config.get_strings("multi5::name"), ["r.sub==p.sub && r.obj==p.obj"])
         with self.assertRaises(ValueError):
             config.get_int("multi5::name")
         with self.assertRaises(ValueError):
